@@ -33,13 +33,13 @@
 class VPNTrayComponent : public TrayComponent
 {
 	Q_OBJECT
-  TQ_OBJECT
+  
 
 	public:
 	  VPNTrayComponent (KSystemTray * parent = 0, const char * name = 0);
 	  ~VPNTrayComponent ();
 
-		void addMenuItems(KPopupMenu* menu);
+		void addMenuItems(TDEPopupMenu* menu);
 
 	public slots:
 		void slotShowNewConnectionDialog();
